<?php
namespace Util\Mail\Core;
use Zend\Mail\Transport\Smtp as SmtpTransport;
use Zend\Mail\Transport\SmtpOptions;
use Zend\Mail\Message as ZendMessage;
use Zend\Mime\Message as ZendMimeMessage;
use Zend\Mime\Part as ZendMimePart;

class SmtpMail extends Mail {

    private $smtpName;
    private $smtpHost;
    private $smtpConnectionClass;
    private $smtpUsername;
    private $smtpPassword;

    public function __construct($name, $host, $user, $password, $class){
        $this->smtpName             = $name;
        $this->smtpHost             = $host;
        $this->smtpConnectionClass  = $class;
        $this->smtpUsername         = $user;
        $this->smtpPassword         = $password;
    }

    private function createSmtpOptions(){
        $options = new SmtpOptions(array(
            'name' => $this->smtpName,
            'host' => $this->smtpHost,
            'connection_class' => $this->smtpConnectionClass,
            'connection_config' => array(
                'username' => $this->smtpUsername,
                'password' => $this->smtpPassword
            )
        ));
        return $options;
    }

    public function send(){
        $email = new ZendMail\Message();
        $email->addTo($this->getTo())
              ->addFrom($this->getFrom())
              ->setSubject($this->getSubject())
              ->setBody(utf8_decode($this->getBody()));
        $transport = new ZendMail\Transport\Smtp();
        $options = $this->createSmtpOptions();
        $transport->setOptions($options);
        $transport->send($email);
    }

    public function sendHtml(){
        $email = new ZendMail\Message();
        $email->addTo($this->getTo())
              ->addFrom($this->getFrom())
              ->setSubject($this->getSubject())
              ->setBody($this->getBody());
        $transport = new ZendMail\Transport\Smtp();
        $options = $this->createSmtpOptions();
        $transport->setOptions($options);
        $transport->send($email);
    }
    
    public function sendHtmlEmail($from, $to, $subject, $body)
    {
        $transport = new SmtpTransport();

        $mimePart = new ZendMimePart($body);
        $mimePart->type = 'text/html';

        $mimeMessage = new ZendMimeMessage();
        $mimeMessage->setParts(array($mimePart));

        $message = new ZendMessage();
        $message->setBody($mimeMessage)->addFrom($from)->addTo($to)->setSubject($subject);

        $transport->setOptions($this->createSmtpOptions());

        $transport->send($message);
    }
}